import React from 'react';
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout';
import Customer from '@/Components/Customer';
//import ContactList from '@/Pages/ContactList/Index';
import InputError from '@/Components/InputError';
import InputLabel from '@/Components/InputLabel';
import TextInput from '@/Components/TextInput';
import PrimaryButton from '@/Components/PrimaryButton';
import { useForm, Head, usePage } from '@inertiajs/react';
import SecondaryButton from '@/Components/SecondaryButton';
//import ContactList from '@/Components/ContactList';
import Contact from '@/Components/Contact';
import ContactList from '@/Pages/ContactList/Index';
import Thing from '@/Components/Thing';
 
export default function Edit() {
	const { auth } = usePage().props;
	
	const customer = usePage().props.customer;
	//const contacts = usePage().props.contacts;
	
    const { data, setData, patch, get, processing, reset, errors } = useForm({
		CustomerId: customer.id,
        CustomerName: customer.CustomerName,
		FirstName: customer.FirstName,
		LastName: customer.LastName,
		BusinessName: customer.BusinessName,
		AddressLine1: customer.AddressLine1,
		AddressLine2: customer.AddressLine2,
		AddressLine3: customer.AddressLine3,
		City: customer.City,
		StateProvince: customer.StateProvince,
		PostalCode: customer.PostalCode,
		Phone1: customer.Phone1,
		Phone2: customer.Phone2,
		Facebook: customer.Facebook,
		Instagram: customer.Instagram,
		TikTok: customer.TikTok,
		YouTube: customer.YouTube,
		EmailAddress: customer.EmailAddress,
		Label: customer.Label,
		Manager: customer.Manager,
		CustomerType: customer.CustomerType,
		Notes: customer.Notes,
		contacts: customer.contacts,
    });
 
    const submit = (e) => {
        e.preventDefault();
        //patch(route('customers.update', customer.id), { onSuccess: () => reset() });
		
        patch(route('customers.update', customer.CustomerId), { onSuccess: () => reset() });
    };
 
    return (
        <AuthenticatedLayout auth={auth}>
            <Head title="Customers" />
 
            <div className="max-w-1xl mx-auto p-4 sm:p-6 lg:p-8">
                <form onSubmit={submit}>
					<PrimaryButton className="mt-4 mb-4" disabled={processing}>Save</PrimaryButton>
					<SecondaryButton className="mt-4 mb-4">Cancel</SecondaryButton>
					
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-customer-name" value="Customer Name" />
							<TextInput
								id="grid-customer-name"
								className="mt-1 block w-full"
								value={data.CustomerName}
								onChange={(e) => setData('CustomerName', e.target.value)}
								required
								// isFocused
								autoComplete="CustomerName"
							/>
							<InputError className="mt-2" message={errors.CustomerName} />
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-business-name" value="Business Name" />
							<TextInput
								id="grid-business-name"
								className="mt-1 block w-full"
								value={data.BusinessName}
								onChange={(e) => setData('BusinessName', e.target.value)}
								// required
								// isFocused
								autoComplete="BusinessName"
							/>
							{/* <InputError className="mt-2" message={errors.BusinessName} /> */}
						</div>
					</div>
					
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-first-name" value="First Name" />
							<TextInput
								id="grid-first-name"
								className="mt-1 block w-full"
								value={data.FirstName}
								onChange={(e) => setData('FirstName', e.target.value)}
								// required
								// isFocused
								autoComplete="FirstName"
							/>
							{/* <InputError className="mt-2" message={errors.FirstName} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-last-name" value="Last Name" />
							<TextInput
								id="grid-last-name"
								className="mt-1 block w-full"
								value={data.LastName}
								onChange={(e) => setData('LastName', e.target.value)}
								// required
								// isFocused
								autoComplete="LastName"
							/>
							{/* <InputError className="mt-2" message={errors.LastName} /> */}
						</div>
					</div>
				
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-address-line-1" value="Address Line 1" />
							<TextInput
								id="grid-address-line-1"
								className="mt-1 block w-full"
								value={data.AddressLine1}
								onChange={(e) => setData('AddressLine1', e.target.value)}
								// required
								// isFocused
								autoComplete="AddressLine1"
							/>
							{/* <InputError className="mt-2" message={errors.AddressLine1} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-address-line-2" value="Address Line 2" />
							<TextInput
								id="grid-address-line-2"
								className="mt-1 block w-full"
								value={data.AddressLine2}
								onChange={(e) => setData('AddressLine2', e.target.value)}
								// required
								// isFocused
								autoComplete="AddressLine2"
							/>
							{/* <InputError className="mt-2" message={errors.AddressLine2} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-address-line-3" value="Address Line 3" />
							<TextInput
								id="grid-address-line-3"
								className="mt-1 block w-full"
								value={data.AddressLine3}
								onChange={(e) => setData('AddressLine3', e.target.value)}
								// required
								// isFocused
								autoComplete="AddressLine3"
							/>
							{/* <InputError className="mt-2" message={errors.AddressLine3} /> */}
						</div>
					</div>
					
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-city" value="City" />
							<TextInput
								id="grid-city"
								className="mt-1 block w-full"
								value={data.City}
								onChange={(e) => setData('City', e.target.value)}
								// required
								// isFocused
								autoComplete="City"
							/>
							{/* <InputError className="mt-2" message={errors.City} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-state-province" value="State/Province" />
							<TextInput
								id="grid-state-province"
								className="mt-1 block w-full"
								value={data.StateProvince}
								onChange={(e) => setData('StateProvince', e.target.value)}
								// required
								// isFocused
								autoComplete="StateProvince"
							/>
							{/* <InputError className="mt-2" message={errors.StateProvince} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-postal-code" value="Postal Code" />
							<TextInput
								id="grid-postal-code"
								className="mt-1 block w-full"
								value={data.PostalCode}
								onChange={(e) => setData('PostalCode', e.target.value)}
								// required
								// isFocused
								autoComplete="PostalCode"
							/>
							{/* <InputError className="mt-2" message={errors.PostalCode} /> */}
						</div>
					</div>
					
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-phone-1" value="Phone 1" />
							<TextInput
								id="grid-phone-1"
								className="mt-1 block w-full"
								value={data.Phone1}
								onChange={(e) => setData('Phone1', e.target.value)}
								// required
								// isFocused
								autoComplete="Phone1"
							/>
							{/* <InputError className="mt-2" message={errors.Phone1} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-phone-2" value="Phone 2" />
							<TextInput
								id="grid-phone-2"
								className="mt-1 block w-full"
								value={data.Phone2}
								onChange={(e) => setData('Phone2', e.target.value)}
								// required
								// isFocused
								autoComplete="Phone2"
							/>
							{/* <InputError className="mt-2" message={errors.Phone2} /> */}
						</div>
					</div>
						
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-facebook" value="Facebook" />
							<TextInput
								id="grid-facebook"
								className="mt-1 block w-full"
								value={data.Facebook}
								onChange={(e) => setData('Facebook', e.target.value)}
								// required
								// isFocused
								autoComplete="Facebook"
							/>
							{/* <InputError className="mt-2" message={errors.Facebook} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-instagram" value="Instagram" />
							<TextInput
								id="grid-instagram"
								className="mt-1 block w-full"
								value={data.Instagram}
								onChange={(e) => setData('Instagram', e.target.value)}
								// required
								// isFocused
								autoComplete="Instagram"
							/>
							{/* <InputError className="mt-2" message={errors.Instagram} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-tiktok" value="TikTok" />
							<TextInput
								id="grid-tiktok"
								className="mt-1 block w-full"
								value={data.TikTok}
								onChange={(e) => setData('TikTok', e.target.value)}
								// required
								// isFocused
								autoComplete="TikTok"
							/>
							{/* <InputError className="mt-2" message={errors.TikTok} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-youtube" value="YouTube" />
							<TextInput
								id="grid-youtube"
								className="mt-1 block w-full"
								value={data.YouTube}
								onChange={(e) => setData('YouTube', e.target.value)}
								// required
								// isFocused
								autoComplete="YouTube"
							/>
							{/* <InputError className="mt-2" message={errors.YouTube} /> */}
						</div>
					</div>
						
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-email-address" value="Email Address" />
							<TextInput
								id="grid-email-address"
								className="mt-1 block w-full"
								value={data.EmailAddress}
								onChange={(e) => setData('EmailAddress', e.target.value)}
								// required
								// isFocused
								autoComplete="EmailAddress"
							/>
							{/* <InputError className="mt-2" message={errors.EmailAddress} /> */}
						</div>
					</div>
					
					<div class="flex wrap mb-4">	
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-label" value="Label" />
							<TextInput
								id="grid-label"
								className="mt-1 block w-full"
								value={data.Label}
								onChange={(e) => setData('Label', e.target.value)}
								// required
								// isFocused
								autoComplete="Label"
							/>
							{/* <InputError className="mt-2" message={errors.Label} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-manager" value="Manager" />
							<TextInput
								id="grid-manager"
								className="mt-1 block w-full"
								value={data.Manager}
								onChange={(e) => setData('Manager', e.target.value)}
								// required
								// isFocused
								autoComplete="Manager"
							/>
							{/* <InputError className="mt-2" message={errors.Manager} /> */}
						</div>
					</div>
					
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-customer-type" value="Customer Type" />
							<TextInput
								id="grid-customer-type"
								className="mt-1 block w-full"
								value={data.CustomerType}
								onChange={(e) => setData('CustomerType', e.target.value)}
								// required
								// isFocused
								autoComplete="CustomerType"
							/>
							<InputError className="mt-2" message={errors.CustomerType} />
						</div>
						
						<label class="block uppercase tracking-wide text-gray-700 text-xs font-bold mb-2" for="grid-customer-type-real">
							Customer Type
						</label>
						<select 
							id="grid-customer-type-real"
							class="block appearance-none w-full bg-white border border-gray-400 hover:border-gray-500 px-4 py-2 pr-8 rounded shadow leading-tight focus:outline-none focus:shadow-outline">
							<option>Individual</option>
							<option>Business</option>
							<option>Band</option>
						</select>
					</div>
					
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-notes" value="Notes" />
							<textarea
								id="grid-notes"
								className="mt-1 block w-full"
								value={data.Notes}
								onChange={(e) => setData('Notes', e.target.value)}
								// required
								// isFocused
								autoComplete="Notes"
							/>
							{/* <InputError className="mt-2" message={errors.Notes} /> */}
						</div>
					</div>
					
                </form>
				
				{/* <div className="mt-6 bg-white shadow-sm rounded-lg divide-y">
                    {customers.map(customer =>
                        <Customer key={customer.id} customer={customer} />
                    )}
                </div> */}
				
				{/* <div className="mt-6 bg-white shadow-sm rounded-lg divide-y"> */}
					
				{/* <div class="overflow-x-auto sm:-mx-6 lg:-mx-8">
					<div class="inline-block min-w-full py-2 sm:px-6 lg:px-8">
						<div class="overflow-hidden">
							<table class="min-w-full text-left text-sm font-light">
								<thead class="border-b font-medium dark:border-neutral-500">
									<tr>
										<th scope="col" class="px-6 py-4">#</th>
										<th scope="col" class="px-6 py-4">Customer Type</th>
										<th scope="col" class="px-6 py-4">Customer Name</th>
										<th scope="col" class="px-6 py-4">First Name</th>
										<th scope="col" class="px-6 py-4">Last Name</th>
										<th scope="col" class="px-6 py-4">Created At</th>
									</tr>
								</thead>
								<tbody>
									{customers.map(customer =>
										<Customer key={customer.id} customer={customer} />
									)}
								</tbody>
							</table>
						</div>
					</div>
				</div> */}
                {/* </div> */}
            </div>
			
			<h2>Contacts</h2>
			{/*<div class="inline-block min-w-full py-2 sm:px-6 lg:px-8">
				<div class="overflow-hidden">
					<table class="min-w-full text-left text-sm font-light">
						<thead class="border-b font-medium dark:border-neutral-500">
							<tr>
								<th scope="col" class="px-6 py-4">#</th>
								<th scope="col" class="px-6 py-4">First Name</th>
								<th scope="col" class="px-6 py-4">Last Name</th>
								<th scope="col" class="px-6 py-4">Title</th>
								<th scope="col" class="px-6 py-4">Phone 1</th>
								<th scope="col" class="px-6 py-4">Email</th>
								<th scope="col" class="px-6 py-4"></th>
							</tr>
						</thead>
						<tbody>
							//{contacts.map(contact =>
							//	<Contact key={contact.id} contact={contact} />
							//)}
							
							<tr
								class="border-b transition duration-300 ease-in-out hover:bg-neutral-100 dark:border-neutral-500 dark:hover:bg-neutral-600">
								<td class="whitespace-nowrap px-6 py-4 font-medium">1</td>
								{//<td class="whitespace-nowrap px-6 py-4">{contact.ContactType}</td>}
								<td class="whitespace-nowrap px-6 py-4">Doug</td>
								<td class="whitespace-nowrap px-6 py-4">Zieme</td>
								<td class="whitespace-nowrap px-6 py-4">Automotive Specialty Technician</td>
								<td class="whitespace-nowrap px-6 py-4">+1-336-967-6526</td>
								<td class="whitespace-nowrap px-6 py-4">genevieve.stracke@example.com</td>
								{// <td class="whitespace-nowrap px-6 py-4"><Link className="mt-4" disabled={processing} href={route('contacts.edit', contact.id)}>Edit</Link></td>}
								{// <td class="whitespace-nowrap px-6 py-4"><PrimaryButton className="mt-4" disabled={processing} href={route('contacts.edit', contact)}>Edit</PrimaryButton><SecondaryButton className="mt-4" disabled={processing}>Other</SecondaryButton></td>}
							</tr>
							<tr
								class="border-b transition duration-300 ease-in-out hover:bg-neutral-100 dark:border-neutral-500 dark:hover:bg-neutral-600">
								<td class="whitespace-nowrap px-6 py-4 font-medium">2</td>
								{// <td class="whitespace-nowrap px-6 py-4">{contact.ContactType}</td>}
								<td class="whitespace-nowrap px-6 py-4">Ashton</td>
								<td class="whitespace-nowrap px-6 py-4">Bahringer</td>
								<td class="whitespace-nowrap px-6 py-4">Precious Stone Worker</td>
								<td class="whitespace-nowrap px-6 py-4">+1 (641) 787-0112</td>
								<td class="whitespace-nowrap px-6 py-4">nasir.welch@example.org</td>
								{// <td class="whitespace-nowrap px-6 py-4"><Link className="mt-4" disabled={processing} href={route('contacts.edit', contact.id)}>Edit</Link></td>}
								{//</AuthenticatedLayout> <td class="whitespace-nowrap px-6 py-4"><PrimaryButton className="mt-4" disabled={//processing} href={route('contacts.edit', contact)}>Edit</PrimaryButton><SecondaryButton className="mt-4" disabled={//processing}>Other</SecondaryButton></td>}
							</tr>
						</tbody>
					</table>
				</div>
			</div> */}
			
			{/* <div>
				<Thing></Thing>
			</div> */}
			
			{/* <div className="p-4 sm:p-8 bg-white shadow sm:rounded-lg">
				<ContactList
					auth = {auth}
				/>
			</div> */}
			
			<div class="inline-block min-w-full py-2 sm:px-6 lg:px-8">
				<div class="overflow-hidden">
					<table class="min-w-full text-left text-sm font-light">
						<thead class="border-b font-medium dark:border-neutral-500">
							<tr>
								<th scope="col" class="px-6 py-4">#</th>
								<th scope="col" class="px-6 py-4">First Name</th>
								<th scope="col" class="px-6 py-4">Last Name</th>
								<th scope="col" class="px-6 py-4">Title</th>
								<th scope="col" class="px-6 py-4">Phone Number</th>
								<th scope="col" class="px-6 py-4">Email</th>
								<th scope="col" class="px-6 py-4"></th>
							</tr>
						</thead>
						<tbody>
							{customer.contacts.map(contact =>
								<Contact key={contact.id} contact={contact} />
							)}
						</tbody>
					</table>
				</div>
			</div>
        </AuthenticatedLayout>
    );
}