import React from 'react';
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout';
import Task from '@/Components/Task';
//import ContactList from '@/Pages/ContactList/Index';
import InputError from '@/Components/InputError';
import InputLabel from '@/Components/InputLabel';
import TextInput from '@/Components/TextInput';
import PrimaryButton from '@/Components/PrimaryButton';
import { useForm, Head, usePage } from '@inertiajs/react';
import SecondaryButton from '@/Components/SecondaryButton';
 
export default function Edit() {
	const { auth } = usePage().props;
	
	const task = usePage().props.task;
	//const contacts = usePage().props.contacts;
	
    const { data, setData, patch, get, processing, reset, errors } = useForm({
		TaskId: task.id,
		TaskName: task.TaskName,
		Customer: task.Customer,
		DueDate: task.DueDate,
		StartDate: task.StartDate,
		Status: task.Status,
		Notes: task.Notes,
    });
	
	//const contacts = get(route('contactlist.index'));
 
    const submit = (e) => {
        e.preventDefault();
        patch(route('tasks.update', task.id), { onSuccess: () => reset() });
    };
 
    return (
        <AuthenticatedLayout auth={auth}>
            <Head title="Tasks" />
 
            <div className="max-w-1xl mx-auto p-4 sm:p-6 lg:p-8">
                <form onSubmit={submit}>
					<PrimaryButton className="mt-4 mb-4" disabled={processing}>Save</PrimaryButton>
					<SecondaryButton className="mt-4 mb-4">Cancel</SecondaryButton>
					
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-task-name" value="Task Name" />
							<TextInput
								id="grid-task-name"
								className="mt-1 block w-full"
								value={data.TaskName}
								onChange={(e) => setData('TaskName', e.target.value)}
								required
								isFocused
								autoComplete="taskName"
							/>
							<InputError className="mt-2" message={errors.TaskName} />
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-customer-name" value="Customer" />
							<TextInput
								id="grid-customer-name"
								className="mt-1 block w-full"
								value={data.Customer}
								onChange={(e) => setData('Customer', e.target.value)}
								// required
								isFocused
								autoComplete="Customer"
							/>
							{/* <InputError className="mt-2" message={errors.Customer} /> */}
						</div>
					</div>
					
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-start-date" value="Start Date" />
							<TextInput
								id="grid-start-date"
								className="mt-1 block w-full"
								value={data.StartDate}
								//value={new Date(data.StartDate).toLocaleString()}
								onChange={(e) => setData('StartDate', e.target.value)}
								// required
								isFocused
								autoComplete="StartDate"
							/>
							{/* <InputError className="mt-2" message={errors.StartDate} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-due-date" value="Due Date" />
							<TextInput
								id="grid-due-date"
								className="mt-1 block w-full"
								value={data.DueDate}
								onChange={(e) => setData('DueDate', e.target.value)}
								// required
								isFocused
								autoComplete="DueDate"
							/>
							{/* <InputError className="mt-2" message={errors.DueDate} /> */}
						</div>
						
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-status" value="Status" />
							<TextInput
								id="grid-status"
								className="mt-1 block w-full"
								value={data.Status}
								onChange={(e) => setData('Status', e.target.value)}
								// required
								isFocused
								autoComplete="Status"
							/>
							{/* <InputError className="mt-2" message={errors.Status} /> */}
						</div>
					</div>
					
					<div class="flex wrap mb-4">
						<div class="w-full px-4">
							<InputLabel htmlFor="grid-notes" value="Notes" />
							<textarea
								id="grid-notes"
								className="mt-1 block w-full"
								value={data.Notes}
								onChange={(e) => setData('Notes', e.target.value)}
								// required
								isFocused
								autoComplete="Notes"
							/>
							{/* <InputError className="mt-2" message={errors.Notes} /> */}
						</div>
					</div>
					
                </form>
				
				{/* <div className="mt-6 bg-white shadow-sm rounded-lg divide-y">
                    {customers.map(customer =>
                        <Customer key={customer.id} customer={customer} />
                    )}
                </div> */}
				
				{/* <div className="mt-6 bg-white shadow-sm rounded-lg divide-y"> */}
					
				{/* <div class="overflow-x-auto sm:-mx-6 lg:-mx-8">
					<div class="inline-block min-w-full py-2 sm:px-6 lg:px-8">
						<div class="overflow-hidden">
							<table class="min-w-full text-left text-sm font-light">
								<thead class="border-b font-medium dark:border-neutral-500">
									<tr>
										<th scope="col" class="px-6 py-4">#</th>
										<th scope="col" class="px-6 py-4">Customer Type</th>
										<th scope="col" class="px-6 py-4">Customer Name</th>
										<th scope="col" class="px-6 py-4">First Name</th>
										<th scope="col" class="px-6 py-4">Last Name</th>
										<th scope="col" class="px-6 py-4">Created At</th>
									</tr>
								</thead>
								<tbody>
									{customers.map(customer =>
										<Customer key={customer.id} customer={customer} />
									)}
								</tbody>
							</table>
						</div>
					</div>
				</div> */}
                {/* </div> */}
            </div>
			
			{/* <div className="p-4 sm:p-8 bg-white shadow sm:rounded-lg">
				<ContactList
					auth = {auth}
				/>
			</div> */}
        </AuthenticatedLayout>
    );
}