<?php

use App\Http\Controllers\CustomerController;
use App\Http\Controllers\CustomerDetailController;
use App\Http\Controllers\TaskController;
use App\Http\Controllers\ContactController;
use App\Http\Controllers\ContactListController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\UserController;
use Illuminate\Foundation\Application;
use Illuminate\Support\Facades\Route;
use Inertia\Inertia;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

// Route::get('/', function () {
//     return Inertia::render('Welcome', [
//         'canLogin' => Route::has('login'),
//         'canRegister' => Route::has('register'),
//         'laravelVersion' => Application::VERSION,
//         'phpVersion' => PHP_VERSION,
//     ]);
// });

Route::get('/', function () {
    return Inertia::render('Dashboard');
})->middleware(['auth', 'verified'])->name('dashboard');

Route::get('/welcome', function(){
    return Inertia::render('Welcome', [
        'canLogin' => Route::has('login'),
        'canRegister' => Route::has('register'),
        'laravelVersion' => Application::VERSION,
        'phpVersion' => PHP_VERSION,
    ]);
});

// Route::get('/dashboard', function () {
//     return Inertia::render('Dashboard');
// })->middleware(['auth', 'verified'])->name('dashboard');

Route::resource('customers', CustomerController::class)
	->only(['index', 'store', 'edit', 'update'])
	->middleware(['auth', 'verified', 'web']);
	
Route::resource('contacts', ContactController::class)
	->only(['index', 'store', 'edit', 'update'])
	->middleware(['auth', 'verified', 'web']);
	
Route::resource('users', UserController::class)
	->only(['index', 'store', 'edit', 'update'])
	->middleware(['auth', 'verified', 'web']);

// Route::resource('customers/edit', CustomerController::class)
// 	->only(['store', 'edit'])
// 	->middleware(['auth', 'verified']);
	
// Route::resource('customers/detail', CustomerDetailController::class)
// 	->only(['index', 'store'])
// 	->middleware(['auth', 'verified']);
	
// Route::resource('customerdetail', CustomerDetailController::class)
// 	->only(['index', 'store'])
// 	->middleware(['auth', 'verified']);
	
Route::resource('tasks', TaskController::class)
	->only(['index', 'store', 'edit', 'update'])
	->middleware(['auth', 'verified']);
	
// Route::resource('contacts', ContactController::class)
// 	->only(['index', 'store', 'view'])
// 	->middleware(['auth', 'verified']);
	
Route::resource('contactlist', ContactListController::class)
	->only(['index', 'store', 'show'])
	->middleware(['auth', 'verified']);
	
// Route::get('/Tasks/NewTask', function () {
// 	return 'Hello World';
// });

Route::get('/tasks/newtask', function () {
    return Inertia::render('Tasks/NewTask');
})->middleware(['auth', 'verified'])->name('NewTask');

Route::get('/tasks/report', function () {
    return Inertia::render('Tasks/Report');
})->middleware(['auth', 'verified'])->name('Report');

Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
});

require __DIR__.'/auth.php';
